"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.filterArguments = exports.cliArguments = void 0;
const file = require("file-exists");
/**
 * A global variable containing a parsed list of loaded CLI arguments by preferred prefix (--) and seperator (=)
 */
exports.cliArguments = loadArguments();
/**
 * Loading the filtered arguments
 */
function loadArguments() {
    let config = file.sync('./cli.config.json') ? require(`${process.env.INIT_CWD}/cli.config.json`) : { prefix: '--', seperator: '=' };
    config = Object.assign(config, filterArguments('--cli-', '='));
    return filterArguments(config.prefix, config.seperator);
}
/**
 * Filtering only relevant arguments by preferred prefix (--) and seperator (=)
 * @param prefix The prefix of the argument
 * @param seperator The seperator of the argument
 */
function filterArguments(prefix, seperator) {
    const finalArgumentsList = {};
    const argumentsList = filterer(prefix, seperator);
    for (const argument of argumentsList) {
        const splitArgument = (seperator !== '') ? argument.split(seperator) : [argument, undefined];
        const name = splitArgument[0].replace(prefix, '');
        const value = (splitArgument[1] !== undefined) ? splitArgument[1] : '';
        finalArgumentsList[name] = value;
    }
    return finalArgumentsList;
}
exports.filterArguments = filterArguments;
/**
 * A filter function to filter by dynamic prefix & seperator
 * @param prefix The prefix of the argument
 * @param seperator The seperator of the argument
 */
function filterer(prefix, seperator) {
    if (prefix !== '' && seperator === '')
        return process.argv.filter((argument) => argument.startsWith(prefix));
    else if (prefix === '' && seperator !== '')
        return process.argv.filter((argument) => argument.indexOf(seperator) !== -1);
    return process.argv;
}
